summaryrefslogtreecommitdiffstats
path: root/src/cli.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/cli.rs')
-rw-r--r--src/cli.rs11
1 files changed, 8 insertions, 3 deletions
diff --git a/src/cli.rs b/src/cli.rs
index d9873d3c..72e91b5a 100644
--- a/src/cli.rs
+++ b/src/cli.rs
@@ -532,9 +532,14 @@ pub struct Opt {
#[structopt(long = "inspect-raw-lines", default_value = "true")]
pub inspect_raw_lines: String,
- /// Whether to use a pager when displaying output. Options are: auto, always, and never. The
- /// default pager is `less`: this can be altered by setting the environment variables
- /// DELTA_PAGER, BAT_PAGER, or PAGER (and that is their order of priority).
+ #[structopt(long)]
+ /// Which pager to use. The default pager is `less`. You can also change pager
+ /// by setting the environment variables DELTA_PAGER, BAT_PAGER, or PAGER
+ /// (and that is their order of priority). This option overrides all environment
+ /// variables above.
+ pub pager: Option<String>,
+
+ /// Whether to use a pager when displaying output. Options are: auto, always, and never.
#[structopt(long = "paging", default_value = "auto")]
pub paging_mode: String,